@@ -12,7 +12,7 @@ def get_sign(data):
         parts.append(data['product_currency'])
     if data.get('order_id'):
         parts.append(data['order_id'])
-    parts.append(conf.PAYMECASH_SECRET_KEY)
+    parts.append(data['secret_key'])
     string = '-'.join(parts)
     sign = hashlib.md5(string).hexdigest()
     return sign
