@@ -2,7 +2,9 @@
 
 import conf
 from django.forms import model_to_dict
+from .signals import payment_fail
 from .signals import payment_process
+from .signals import payment_completed
 from django.db import models
 
 
@@ -64,9 +66,14 @@ class Payment(models.Model):
         )
 
     def save(self, *args, **kwargs):
+        data = model_to_dict(self)
         if self.pk is None:
-            data = model_to_dict(self)
             payment_process.send(sender=self, data=data)
+        else:
+            if self.result == self.RESULT_OK:
+                payment_completed.send(sender=self, data=data)
+            if self.result == self.RESULT_ERROR:
+                payment_fail.send(sender=self, data=data)
         super(Payment, self).save(*args, **kwargs)
 
     class Meta:
